@@ -2,10 +2,10 @@ package Encode::Alias;
 use strict;
 use warnings;
 no warnings 'redefine';
-our $VERSION = do { my @r = ( q$Revision: 2.11 $ =~ /\d+/g ); sprintf "%d." . "%02d" x $#r, @r };
-sub DEBUG () { 0 }
+our $VERSION = do { my @r = ( q$Revision: 2.20 $ =~ /\d+/g ); sprintf "%d." . "%02d" x $#r, @r };
+use constant DEBUG => !!$ENV{PERL_ENCODE_DEBUG};
 
-use base qw(Exporter);
+use Exporter 'import';
 
 # Public, encouraged API is exported by default
 
@@ -90,9 +90,9 @@ sub define_alias {
                     DEBUG and warn "delete \$Alias\{$k\}";
                     delete $Alias{$k};
                 }
-                elsif ( ref($alias) eq 'CODE' ) {
+                elsif ( ref($alias) eq 'CODE' && $alias->($k) ) {
                     DEBUG and warn "delete \$Alias\{$k\}";
-                    delete $Alias{ $alias->($name) };
+                    delete $Alias{$k};
                 }
             }
         }
@@ -139,7 +139,7 @@ sub init_aliases {
     define_alias( qr/^UCS-?2-?LE$/i => '"UCS-2LE"' );
     define_alias(
         qr/^UCS-?2-?(BE)?$/i    => '"UCS-2BE"',
-        qr/^UCS-?4-?(BE|LE)?$/i => 'uc("UTF-32$1")',
+        qr/^UCS-?4-?(BE|LE|)?$/i => 'uc("UTF-32$1")',
         qr/^iso-10646-1$/i      => '"UCS-2BE"'
     );
     define_alias(
@@ -206,11 +206,12 @@ sub init_aliases {
     # Mac Mappings
     # predefined in *.ucm; unneeded
     # define_alias( qr/\bmacIcelandic$/i => '"macIceland"');
-    define_alias( qr/^mac_(.*)$/i => '"mac$1"' );
+    define_alias( qr/^(?:x[_-])?mac[_-](.*)$/i => '"mac$1"' );
     # http://rt.cpan.org/Ticket/Display.html?id=36326
     define_alias( qr/^macintosh$/i => '"MacRoman"' );
-
-    # Ououououou. gone.  They are differente!
+    # https://rt.cpan.org/Ticket/Display.html?id=78125
+    define_alias( qr/^macce$/i => '"MacCentralEurRoman"' );
+    # Ououououou. gone.  They are different!
     # define_alias( qr/\bmacRomanian$/i => '"macRumanian"');
 
     # Standardize on the dashed versions.
@@ -255,8 +256,12 @@ sub init_aliases {
         define_alias( qr/\bhk(?:scs)?[-_]?big5$/i => '"big5-hkscs"' );
     }
 
+    # https://github.com/dankogai/p5-encode/issues/37
+    define_alias(qr/cp65000/i => '"UTF-7"');
+    define_alias(qr/cp65001/i => '"utf-8-strict"');
+
     # utf8 is blessed :)
-    define_alias( qr/^UTF-8$/i => '"utf-8-strict"' );
+    define_alias( qr/\bUTF-8$/i => '"utf-8-strict"' );
 
     # At last, Map white space and _ to '-'
     define_alias( qr/^(\S+)[\s_]+(.*)$/i => '"$1-$2"' );
@@ -286,7 +291,9 @@ Encode::Alias - alias definitions to encodings
 
   use Encode;
   use Encode::Alias;
-  define_alias( newName => ENCODING);
+  define_alias( "newName" => ENCODING);
+  define_alias( qr/.../ => ENCODING);
+  define_alias( sub { return ENCODING if ...; } );
 
 =head1 DESCRIPTION
 
@@ -294,7 +301,8 @@ Allows newName to be used as an alias for ENCODING. ENCODING may be
 either the name of an encoding or an encoding object (as described 
 in L<Encode>).
 
-Currently I<newName> can be specified in the following ways:
+Currently the first argument to define_alias() can be specified in the
+following ways:
 
 =over 4
 
@@ -321,7 +329,7 @@ experienced.  Use this feature with caution.
 
 The same effect as the example above in a different way.  The coderef
 takes the alias name as an argument and returns a canonical name on
-success or undef if not.  Note the second argument is not required.
+success or undef if not.  Note the second argument is ignored if provided.
 Use this with even more caution than the regex version.
 
 =back
@@ -334,7 +342,7 @@ As of Encode 1.87, the older form
 
 no longer works. 
 
-Encode up to 1.86 internally used "local $_" to implement ths older
+Encode up to 1.86 internally used "local $_" to implement this older
 form.  But consider the code below;
 
   use Encode;
@@ -369,6 +377,10 @@ to do so.  And
 
 gets the factory settings back.
 
+Note that define_alias() will not be able to override the canonical name
+of encodings. Encodings are first looked up by canonical name before
+potential aliases are tried.
+
 =head1 SEE ALSO
 
 L<Encode>, L<Encode::Supported>
